pub struct Thesaurus {
pub source_hash: Option<String>,
/* private fields */
}Expand description
A thesaurus is a dictionary with synonyms which map to upper-level concepts.
Fields
source_hash: Option<String>SHA-256 hash of the source markdown files used to build this thesaurus. Used for cache invalidation: when the hash changes, the thesaurus is rebuilt.
Implementations
Sourceimpl Thesaurus
impl Thesaurus
Sourcepub fn with_source_hash(self, hash: String) -> Self
pub fn with_source_hash(self, hash: String) -> Self
Set the source hash for cache invalidation tracking.
Sourcepub fn insert(&mut self, key: NormalizedTermValue, value: NormalizedTerm)
pub fn insert(&mut self, key: NormalizedTermValue, value: NormalizedTerm)
Inserts a key-value pair into the thesaurus.
Sourcepub fn get(&self, key: &NormalizedTermValue) -> Option<&NormalizedTerm>
pub fn get(&self, key: &NormalizedTermValue) -> Option<&NormalizedTerm>
Custom get method for the thesaurus, which accepts a
NormalizedTermValue and returns a reference to the
NormalizedTerm.
pub fn keys(&self) -> Keys<'_, NormalizedTermValue, NormalizedTerm>